version 8.2
clear
set logtype text
set more off
set matsize 200

capture log close
log using "brazrloc/logs/wtf-data.log", replace

* mapping wtf to regiao
tempfile regiao
use wtfkey regiao using "brazaux/conc/countries/country-table.dta", clear
duplicates drop
drop if wtfkey==.
rename wtfkey _wtfkey
gen str6 wtfkey=string(_wtfkey)
drop _wtfkey
sort wtfkey
save `regiao'

* annual country-level data (aggregated over sector)
use icode importer ecode exporter value86-value98 using "$extdata/brazaux/intl/nber/wtf_bilat.dta", clear
collapse (sum) value86-value98, by(icode importer) fast
rename icode wtfkey
drop if wtfkey=="100000" | wtfkey=="999990"  // world or intl organizations

* country-level aggregates
sort wtfkey
joinby using `regiao', unmatched(both) _merge(_merge)
qui count if _m~=3
if `r(N)'>0  STOP  // unmatched wtf country codes
drop _m
list wtfkey if regiao==""

* region-level (Brazilian export-weighted) aggregates, by sector and year
preserve
drop if wtfkey=="330760"   // drop Brazil
gen long _wtfkey = int(real(wtfkey))
drop wtfkey
rename _wtfkey wtfkey
sort wtfkey
joinby wtfkey using "brazrloc/auxil/subsibge-country-exp90.dta", _merge(_merge) unmatched(both)
qui count if _m~=3 & wtfkey~=330760
if `r(N)'~=0  STOP
collapse (sum) value86-value98 [w=expweight], by(subs_ibge regiao) fast
reshape long value, i(subs_ibge regiao) j(year)
replace year = year + 1900
label var year "Calendar year"
rename value imp
label var imp "Regional imports (excl. Brazil)"
rename imp imp_
reshape wide imp_, i(subs_ibge year) j(regiao) string
foreach reg in $regdef {
  label var imp_`reg' "Non-Brazil Imports in `reg'"
  }
compress
sort subs_ibge year
save "brazrloc/auxil/wtf-subsibge-data.dta", replace
restore

* region-level aggregates, by year
preserve
drop if wtfkey=="330760"   // drop Brazil
collapse (sum) value86-value98, by(regiao) fast
reshape long value, i(regiao) j(year)
replace year = year + 1900
label var year "Calendar year"
rename value imp
label var imp "Regional imports (excl. Brazil)"
rename imp imp_
reshape wide imp_, i(year) j(regiao) string
foreach reg in $regdef {
  label var imp_`reg' "Non-Brazil Imports in `reg'"
  }
compress
sort year
save "brazrloc/auxil/wtf-data.dta", replace
restore

log close
