version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/pme"

capture log close
log using "brazrloc/logs/pme-stats.log", replace

// PME: METROPOLITAN MALE WORKERS

* COMPARISON TO RAIS, METROPOLITAN PRIME-AGE MALES, ANNUAL LABOR MARKET TRANSITIONS 1990-98

use "brazrloc/tex/v4/pme/tabelas", clear
keep year formal_informal formal_formal formal_self_employment formal_unemployed_fora_da_pea
drop if year<1986 | year>1997
order year formal_formal formal_informal formal_self_employment formal_unemployed_fora_da_pea
foreach var in formal informal self_employment unemployed_fora_da_pea {
  replace formal_`var' = formal_`var'/100
  }
gen str7 _rowname = string(year)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
* report
graph bar (mean) formal_formal formal_informal formal_self_employment formal_unemployed_fora_da_pea, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self employed") label(4 "Unemployed or withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/labmkttrns-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex formal_*, type(mean) r(_dummy) c(year) categ(formal_) p(brazrloc/tex/v4/pme) name(labmkttrns_86_98) fancy replace over nolog
restore

* (A) ALLOCATION OF WORKERS ACROSS SECTORS (INDEPENDENT OF WORK STATUS)

use "brazrloc/tex/v4/pme/tabelas", clear
keep year workers*
drop if year<1986 | year>1998
order year workers_in_manufacturing workers_in_construction workers_in_retail workers_in_services workers_in_agriculture workers_in_public_adm
foreach sec in manufacturing construction retail services agriculture public_adm {
  replace workers_in_`sec' = workers_in_`sec'/100
  rename workers_in_`sec' emplsh_`sec'
  }
egen emplsh_other = rsum(emplsh_agriculture emplsh_construction emplsh_public_adm)
drop emplsh_agriculture emplsh_construction emplsh_public_adm
* report
graph bar (mean) emplsh_manufacturing emplsh_retail emplsh_services emplsh_other, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Manufacturing") label(2 "Commerce") label(3 "Services") label(4 "Primary & Other") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/emplshare-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex emplsh_*, type(mean) r(_dummy) c(year) categ(emplsh_) p(brazrloc/tex/v4/pme) name(emplshare_86_98) fancy replace over nolog
restore

* (B) ALLOCATION OF FORMAL WORKERS ACROSS SECTORS

use "brazrloc/tex/v4/pme/tabelas", clear
keep year stock_of_formal_in_manufacturing stock_of_formal_in_construction stock_of_formal_in_retail stock_of_formal_in_services stock_of_formal_in_agriculture stock_of_formal_in_public_adm
drop if year<1986 | year>1998
order year stock_of_formal_in_manufacturing stock_of_formal_in_construction stock_of_formal_in_retail stock_of_formal_in_services stock_of_formal_in_agriculture stock_of_formal_in_public_adm
foreach sec in manufacturing construction retail services agriculture public_adm {
  replace stock_of_formal_in_`sec' = stock_of_formal_in_`sec'/100
  rename stock_of_formal_in_`sec' frmemplsh_`sec'
  }
egen frmemplsh_other = rsum(frmemplsh_agriculture frmemplsh_construction frmemplsh_public_adm)
* report
graph bar (mean) frmemplsh_manufacturing frmemplsh_retail frmemplsh_services frmemplsh_other, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Manufacturing") label(2 "Commerce") label(3 "Services") label(4 "Primary & Other") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/formemplshare-86-98.eps", replace
drop frmemplsh_other
egen frmemplsh_other = rsum(frmemplsh_construction frmemplsh_public_adm)
drop frmemplsh_construction frmemplsh_public_adm
gen int frmemplsh_mining = -999
order year frmemplsh_agriculture frmemplsh_mining frmemplsh_manufacturing frmemplsh_retail frmemplsh_services frmemplsh_other
gen byte _dummy = 1
preserve
tabl2tex frmemplsh_*, type(mean) r(_dummy) c(year) categ(frmemplsh_) p(brazrloc/tex/v4/pme) name(formemplshare_86_98) fancy replace over nolog
restore

* (C) WORK STATUS OVER TIME

use "brazrloc/tex/v4/pme/tabelas", clear
keep year informal_workers formal_workers self_employment_workers unemployed_workers fora_da_pea_workers
drop if year<1986 | year>1998
order year formal_workers informal_workers self_employment_workers unemployed_workers fora_da_pea_workers
foreach var in formal informal self_employment unemployed fora_da_pea {
  replace `var'_workers = `var'_workers/100
  }
* report
graph twoway connected formal_workers informal_workers self_employment_workers unemployed_workers fora_da_pea_workers year, ytitle("Share") xtitle("Year") xlabel(1986(2)1998) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed") label(5 "Withdrawn") ) graphregion(color(white)) scheme(sj) msymbol(O D T S + X) clpattern(solid dash_dot solid dash longdash_dot)
graph export "brazrloc/graphs/v4/pme/workstatus-86-98.eps", replace
graph bar (mean) formal_workers informal_workers self_employment_workers unemployed_workers fora_da_pea_workers, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed") label(5 "Withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/workstatus-bar-86-98.eps", replace
graph bar (mean) formal_workers informal_workers self_employment_workers unemployed_workers, over(year) stack ytitle("Share") yscale(range(0 1)) ylabel(0(.2)1) yline(0(.2)1, lcolor(gs14)) blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed") label(5 "Withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10))  /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/workstatus-bar-nowithdr-86-98.eps", replace

* (D) SHARE OF FORMAL WORKERS BY SECTOR

use "brazrloc/tex/v4/pme/tabelas", clear
keep year share_of_formal_in_manufacturing share_of_formal_in_construction share_of_formal_in_retail share_of_formal_in_services share_of_formal_in_agriculture share_of_formal_in_public_adm
drop if year<1986 | year>1998
order year share_of_formal_in_manufacturing share_of_formal_in_construction share_of_formal_in_retail share_of_formal_in_services share_of_formal_in_agriculture share_of_formal_in_public_adm
foreach sec in manufacturing construction retail services agriculture public_adm {
  replace share_of_formal_in_`sec' = share_of_formal_in_`sec'/100
  rename share_of_formal_in_`sec' formsh_`sec'
  }
egen formsh_other = rsum(formsh_construction formsh_public_adm)
drop formsh_construction formsh_public_adm
* report
graph twoway connected formsh_agriculture formsh_manufacturing formsh_retail formsh_services formsh_other year, ytitle("Share") xtitle("Year") xlabel(1986(2)1998) legend( label(1 "Primary") label(2 "Manufacturing") label(3 "Commerce") label(4 "Services") label(5 "Other") ) graphregion(color(white)) scheme(sj) msymbol(O D T S + X) clpattern(solid dash_dot solid dash longdash_dot)
graph export "brazrloc/graphs/v4/pme/formshare-86-98.eps", replace

* (E) ANNUAL TRANSITIONS FROM FORMAL WORK STATUS IN MANUFACTURING

use "brazrloc/tex/v4/pme/tabelas", clear
keep year formal_informal formal_formal formal_self_employment formal_unemployed_fora_da_pea 
drop if year<1986 | year>1997
order year formal_formal formal_informal formal_self_employment formal_unemployed_fora_da_pea
foreach var in formal informal self_employment unemployed_fora_da_pea {
  replace formal_`var' = formal_`var'/100
  }
gen str7 _rowname = string(year)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
* report
graph bar (mean) formal_formal formal_informal formal_self_employment formal_unemployed_fora_da_pea, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed or withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/formtrans-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex formal_*, type(mean) r(_dummy) c(year) categ(formal_) p(brazrloc/tex/v4/pme) name(formtrans_86_98) fancy replace over nolog
restore

* (F) ANNUAL TRANSITIONS FROM INFORMAL WORK STATUS IN MANUFACTURING

use "brazrloc/tex/v4/pme/tabelas", clear
keep year informal_informal informal_formal informal_self_employment informal_unemployed_fora_da_pea 
drop if year<1986 | year>1997
order year informal_formal informal_informal informal_self_employment informal_unemployed_fora_da_pea
foreach var in formal informal self_employment unemployed_fora_da_pea {
  replace informal_`var' = informal_`var'/100
  }
gen str7 _rowname = string(year)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
* report
graph bar (mean) informal_formal informal_informal informal_self_employment informal_unemployed_fora_da_pea, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed or withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/informtrans-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex informal_*, type(mean) r(_dummy) c(year) categ(informal_) p(brazrloc/tex/v4/pme) name(informtrans_86_98) fancy replace over nolog
restore

log close
