version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/natl"
capture mkdir "brazrloc/tex/v4/natl/trans"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime/trans"
capture mkdir "brazrloc/tex/v4/metromale"
capture mkdir "brazrloc/tex/v4/metromale/trans"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime/trans"

capture log close
log using "brazrloc/logs/transitions.log", replace


// RAIS: METROPOLITAN MALE WORKERS, 5-PERCENT SAMPLE //
//---------------------------------------------------//

* METROPOLITAN PRIME-AGE MALES, SECTOR TRANSITIONS
*-------------------------------------------------

use wid ano identificad mes_deslig rem_media subs_ibge municipio caus_desl_tc fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* prepare unaccounted category (post-retirement or death to be excluded, resetting aggsec=9 and tradsec=9 to .)
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid year)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid year rem_media
by wid year: keep if _n==_N
drop rem_media

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge cnae 1995 sector and comparative advantage information (for 1986-98)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98", nokeep
tab _m  // _m==1: years 1999-2001 (but mod_clas_cnae_95==. also for _m==3 when firm not recorded in 1995)
count if mod==. & _m==3
drop _m indcnts13
rename ano year
rename mod_clas_cnae_95 cnae
sort cnae year
merge cnae year using "brazaux/intl/balassa-compadv-cnae", nokeep
rename cnae mod_clas_cnae_95
tab _m  // _m==1: nontraded sectors and years 1999-2001
tab subs_ibge if _m==1 & year<=1998
tab year if _m==1
drop wrld_exp wrld_tot braz_exp braz_tot balcadv
gen byte cnaesec = 7 if _m==1 & year<=1998 & mod_clas_cnae_95~=.  // no Balassa traded good sector merge, but also not missing 1995 sector information
forvalues i=1/5 {
  replace cnaesec = `i' if balarank==`i'
  }
label var cnaesec "CNAE/Balassa Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values cnaesec tradsec
drop _m balarank mod_clas_cnae_95

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank

* redefine aggsec to merge agriculture and mining into primary
replace aggsec = 0 if aggsec==1 | aggsec==2

* merge export status information by firm
sort cnpj_radic year
rename year ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid year
replace aggsec = 9 if _fillin
replace tradsec = 9 if _fillin
replace cnaesec = 9 if _fillin & year<=1998
sort wid year
by wid: replace rm = rm[_n-1] if _fillin
drop _fillin

* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
sort wid year
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 | fx_etaria[_n-8]==8 | fx_etaria[_n-9]==8 | fx_etaria[_n-10]==8 | fx_etaria[_n-11]==8 | fx_etaria[_n-12]==8 | fx_etaria[_n-13]==8 | fx_etaria[_n-14]==8 | fx_etaria[_n-15]==8 | fx_etaria[_n-16]==8 ) ) )
drop fx_etaria
replace aggsec = . if indretired
replace tradsec = . if indretired
drop indretired _retiryr _deathyr

* finalize
sort wid year subs_ibge
tsset wid year
codebook wid year

* TRADED GOODS SECTOR DEFINITION

tab indexp aggsec
ta2tex indexp aggsec, m(expsec_empl) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy digits(3) thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
ta2tex indexp aggsec, col m(expsec_empl_col) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy digits(3)

* SECTOR TRANSITIONS

tab aggsec
qui label save aggsec using "brazrloc/tex/v4/metromale-prime/trans/aggsec", replace
* xttrans aggsec if aggsec<9 & rm==rm[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex aggsec if aggsec<9 & rm==rm[_n+1], m(xtcs_aggsec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9 & rm==rm[_n+1], m(xtcs_aggsec_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
*xttrans2tex aggsec if aggsec<9 & rm==rm[_n+1] & year>=1986 & year<=1990, m(xtcs_aggsec_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & rm==rm[_n+1] & year>=1990 & year<=1994, m(xtcs_aggsec_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & rm==rm[_n+1] & year>=1994 & year<=1998, m(xtcs_aggsec_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)

* separations only (separations from firms)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_aggsec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_aggsec_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1986 & year<=1990, m(xts_aggsec_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1994, m(xts_aggsec_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1994 & year<=1998, m(xts_aggsec_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(aggsec) digits(1) scale(100)

* TRADED SECTOR TRANSITIONS, BASED ON SUBSIBGE

tab tradsec
qui label save tradsec using "brazrloc/tex/v4/metromale-prime/trans/tradsec", replace
* xttrans tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_unac) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_unac_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_unac_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_unac_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_unac_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_unac_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_unac_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status, at 4-year horizon
preserve
  keep if year==1986 | year==1990 | year==1994 | year==1998
  sort wid year
  tsset wid year
  xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_unac_4yr) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
restore

* TRADED SECTOR TRANSITIONS 1986-98, BASED ON CNAE 95 FOR 1995-SURVIVOR FIRMS

tab cnaesec
* xttrans cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_cnaesec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_cnaesec_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_cnaesec_unac) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_cnaesec_unac_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_unac_86_90) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_unac_90_94) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_unac_94_98) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_unac_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_unac_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* FIRM TRANSITIONS (EXPORTERS 1990-98)

tab indexp
qui label save indexp using "brazrloc/tex/v4/metromale-prime/trans/indexp", replace
* xttrans indexp if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex indexp if rm==rm[_n+1], m(xtcs_indexp) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if rm==rm[_n+1], m(xtcs_indexp_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]

* continuations and separations, reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1] & rm==rm[_n+1], m(xtcs_indexp_insec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1] & rm==rm[_n+1], m(xtcs_indexp_num_insec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]

* separations only (separations from firms)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_indexp_num_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_indexp_num_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]

* separations only (separations from firms), reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp_insec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp_num_insec) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]

* separations only (separations from firms), reabsorptions within manufacturing
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp_manf) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_indexp_manf_num) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1990 & year<=1991, m(xts_indexp_manf_num_90_91) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1] & year>=1996 & year<=1997, m(xts_indexp_manf_num_96_97) replace path(brazrloc/tex/v4/metromale-prime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]


// RAIS: NATIONAL WORKERS, 1-PERCENT SAMPLE //
//------------------------------------------//

* NATIONAL PRIME-AGE MALES, SECTOR TRANSITIONS
*---------------------------------------------

use wid ano identificad mes_deslig rem_media subs_ibge municipio caus_desl_tc fx_etaria sexo using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop sexo
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* prepare unaccounted category (post-retirement or death to be excluded, resetting aggsec=9 and tradsec=9 to .)
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid year)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid year rem_media
by wid year: keep if _n==_N
drop rem_media

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge cnae 1995 sector and comparative advantage information (for 1986-98)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98", nokeep
tab _m  // _m==1: years 1999-2001 (but mod_clas_cnae_95==. also for _m==3 when firm not recorded in 1995)
count if mod==. & _m==3
drop _m indcnts13
rename ano year
rename mod_clas_cnae_95 cnae
sort cnae year
merge cnae year using "brazaux/intl/balassa-compadv-cnae", nokeep
rename cnae mod_clas_cnae_95
tab _m  // _m==1: nontraded sectors and years 1999-2001
tab subs_ibge if _m==1 & year<=1998
tab year if _m==1
drop wrld_exp wrld_tot braz_exp braz_tot balcadv
gen byte cnaesec = 7 if _m==1 & year<=1998 & mod_clas_cnae_95~=.  // no Balassa traded good sector merge, but also not missing 1995 sector information
forvalues i=1/5 {
  replace cnaesec = `i' if balarank==`i'
  }
label var cnaesec "CNAE/Balassa Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values cnaesec tradsec
drop _m balarank mod_clas_cnae_95

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank

* redefine aggsec to merge agriculture and mining into primary
replace aggsec = 0 if aggsec==1 | aggsec==2

* merge export status information by firm
sort cnpj_radic year
rename year ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year

* define four exporter-sector categories within traded goods
gen byte aggsecexp = 1 if aggsec==0 & indexp==0
replace aggsecexp = 2 if aggsec==0 & indexp==1
replace aggsecexp = 3 if aggsec==3 & indexp==0
replace aggsecexp = 4 if aggsec==3 & indexp==1
replace aggsecexp = 5 if aggsec==4 | aggsec==5 | aggsec==6
label define aggsecexp 1 "Nonexp. Primary" 2 "Exp. Primary" 3 "Nonexp. Manufact." 4 "Exp. Manufact." 5 "Nontraded" 9 "n/a", modify
label var aggsecexp "Aggregate Sector x Exporter"
label values aggsecexp aggsecexp
replace aggsecexp = . if year<1990 | year>2001  // no SECEX information prior to 1990 or after 2001

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid year
replace aggsec = 9 if _fillin
replace tradsec = 9 if _fillin
replace cnaesec = 9 if _fillin & year<=1998
replace aggsecexp = 9 if _fillin & year>=1990 & year<=1998
sort wid year
by wid: replace rm = rm[_n-1] if _fillin
drop _fillin

* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
sort wid year
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 | fx_etaria[_n-8]==8 | fx_etaria[_n-9]==8 | fx_etaria[_n-10]==8 | fx_etaria[_n-11]==8 | fx_etaria[_n-12]==8 | fx_etaria[_n-13]==8 | fx_etaria[_n-14]==8 | fx_etaria[_n-15]==8 | fx_etaria[_n-16]==8 ) ) )
drop fx_etaria
replace aggsec = . if indretired
replace tradsec = . if indretired
replace aggsecexp = . if indretired
drop indretired _retiryr _deathyr

* finalize
sort wid year subs_ibge
tsset wid year
codebook wid year

* TRADED GOODS SECTOR DEFINITION

tab indexp aggsec
ta2tex indexp aggsec, m(expsec_empl) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy digits(3) thousep scale(.00002)  // in millions, scaled by 20 to account for 5% sample [20/1000000]
ta2tex indexp aggsec, col m(expsec_empl_col) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy digits(3)

* SECTOR TRANSITIONS

tab aggsec
qui label save aggsec using "brazrloc/tex/v4/natl-maleprime/trans/aggsec", replace
* xttrans aggsec  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex aggsec if aggsec<9, m(xtcs_aggsec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9, m(xtcs_aggsec_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex aggsec if aggsec<9 & year>=1986 & year<=1990, m(xtcs_aggsec_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & year>=1990 & year<=1994, m(xtcs_aggsec_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & year>=1994 & year<=1998, m(xtcs_aggsec_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)

* separations only (separations from firms)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsec_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_aggsec_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_aggsec_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_aggsec_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsec) digits(1) scale(100)

* TRADED SECTOR TRANSITIONS, BASED ON SUBSIBGE

tab tradsec
qui label save tradsec using "brazrloc/tex/v4/natl-maleprime/trans/tradsec", replace
* xttrans tradsec if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_unac) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_unac_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_unac_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_unac_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_unac_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_unac_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_unac_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status, at 4-year horizon
preserve
  keep if year==1986 | year==1990 | year==1994 | year==1998
  sort wid year
  tsset wid year
  xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_unac_4yr) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
restore

* TRADED SECTOR AND EXPORTER TRANSITIONS, BASED ON SUBSIBGE

tab aggsecexp
tab aggsecexp if aggsecexp~=9
qui label save aggsecexp using "brazrloc/tex/v4/natl-maleprime/trans/aggsecexp", replace
* xttrans tradsec if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsecexp_unac) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(1) scale(100)
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsecexp_unac_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_aggsecexp_unac_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(1) scale(100)
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_aggsecexp_unac_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(1) scale(100)
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_aggsecexp_unac_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(1) scale(100)
xttrans2tex aggsecexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_aggsecexp_unac_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(aggsecexp) digits(1) scale(100)

* TRADED SECTOR TRANSITIONS 1986-98, BASED ON CNAE 95 FOR 1995-SURVIVOR FIRMS

tab cnaesec
* xttrans cnaesec if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_unac) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_unac_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_unac_86_90) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_unac_90_94) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_unac_94_98) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_unac_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_unac_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(tradsec) digits(1) scale(100)

* FIRM TRANSITIONS (EXPORTERS 1990-98)

tab indexp
qui label save indexp using "brazrloc/tex/v4/natl-maleprime/trans/indexp", replace
* xttrans indexp if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex indexp, m(xtcs_indexp) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp, m(xtcs_indexp_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* continuations and separations, reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1], m(xtcs_indexp_insec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1], m(xtcs_indexp_num_insec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_indexp_num_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_indexp_num_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms), reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_insec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_num_insec) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms), reabsorptions within manufacturing
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_manf) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_manf_num) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_indexp_manf_num_90_91) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_indexp_manf_num_96_97) replace path(brazrloc/tex/v4/natl-maleprime/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]


* NATIONAL SECTOR TRANSITIONS
*----------------------------

use wid ano identificad mes_deslig rem_media subs_ibge municipio caus_desl_tc fx_etaria using "brazrloc/data/wid-draw-workers-natl", clear
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* prepare unaccounted category (post-retirement or death to be excluded, resetting aggsec=9 and tradsec=9 to .)
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid year)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid year rem_media
by wid year: keep if _n==_N
drop rem_media

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge cnae 1995 sector and comparative advantage information (for 1986-98)
rename year ano
sort cnpj_radic ano
merge cnpj_radic ano using "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98", nokeep
tab _m  // _m==1: years 1999-2001 (but mod_clas_cnae_95==. also for _m==3 when firm not recorded in 1995)
count if mod==. & _m==3
drop _m indcnts13
rename ano year
rename mod_clas_cnae_95 cnae
sort cnae year
merge cnae year using "brazaux/intl/balassa-compadv-cnae", nokeep
rename cnae mod_clas_cnae_95
tab _m  // _m==1: nontraded sectors and years 1999-2001
tab subs_ibge if _m==1 & year<=1998
tab year if _m==1
drop wrld_exp wrld_tot braz_exp braz_tot balcadv
gen byte cnaesec = 7 if _m==1 & year<=1998 & mod_clas_cnae_95~=.  // no Balassa traded good sector merge, but also not missing 1995 sector information
forvalues i=1/5 {
  replace cnaesec = `i' if balarank==`i'
  }
label var cnaesec "CNAE/Balassa Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values cnaesec tradsec
drop _m balarank mod_clas_cnae_95

* merge aggregate sector and comparative advantage information
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot balcadv
rename subsibge subs_ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP  // incomplete sector information
drop _m
qui do "brazrloc/auxil/aggsec.do"
label values aggsec aggsec
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
drop balarank

* redefine aggsec to merge agriculture and mining into primary
replace aggsec = 0 if aggsec==1 | aggsec==2

* merge export status information by firm
sort cnpj_radic year
rename year ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year

* identify metropolitan areas and fillin worker panels
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
fillin wid year
replace aggsec = 9 if _fillin
replace tradsec = 9 if _fillin
replace cnaesec = 9 if _fillin & year<=1998
sort wid year
by wid: replace rm = rm[_n-1] if _fillin
drop _fillin

* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
sort wid year
by wid: gen byte indretired = ( cnpj_radic==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 | fx_etaria[_n-8]==8 | fx_etaria[_n-9]==8 | fx_etaria[_n-10]==8 | fx_etaria[_n-11]==8 | fx_etaria[_n-12]==8 | fx_etaria[_n-13]==8 | fx_etaria[_n-14]==8 | fx_etaria[_n-15]==8 | fx_etaria[_n-16]==8 ) ) )
drop fx_etaria
replace aggsec = . if indretired
replace tradsec = . if indretired
drop indretired _retiryr _deathyr

* finalize
sort wid year subs_ibge
tsset wid year
codebook wid year

* TRADED GOODS SECTOR DEFINITION

tab indexp aggsec
ta2tex indexp aggsec, m(expsec_empl) replace path(brazrloc/tex/v4/natl/trans) fancy digits(3) thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
ta2tex indexp aggsec, col m(expsec_empl_col) replace path(brazrloc/tex/v4/natl/trans) fancy digits(3)

* SECTOR TRANSITIONS

tab aggsec
qui label save aggsec using "brazrloc/tex/v4/natl/trans/aggsec", replace
* xttrans aggsec  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex aggsec if aggsec<9, m(xtcs_aggsec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9, m(xtcs_aggsec_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex aggsec if aggsec<9 & year>=1986 & year<=1990, m(xtcs_aggsec_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & year>=1990 & year<=1994, m(xtcs_aggsec_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & year>=1994 & year<=1998, m(xtcs_aggsec_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)

* separations only (separations from firms)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_aggsec_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_aggsec_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_aggsec_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)
*xttrans2tex aggsec if aggsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_aggsec_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(aggsec) digits(1) scale(100)

* TRADED SECTOR TRANSITIONS, BASED ON SUBSIBGE

tab tradsec
qui label save tradsec using "brazrloc/tex/v4/natl/trans/tradsec", replace
* xttrans tradsec if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if tradsec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_unac) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1], m(xts_tradsec_unac_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_tradsec_unac_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_tradsec_unac_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_tradsec_unac_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_tradsec_unac_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_tradsec_unac_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)

preserve
  keep if year==1986 | year==1990 | year==1994 | year==1998
  sort wid year
  tsset wid year
  xttrans2tex tradsec if cnpj_radic~=cnpj_radic[_n+1] & rm==rm[_n+1], m(xts_tradsec_unac_4yr) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
restore

* TRADED SECTOR TRANSITIONS 1986-98, BASED ON CNAE 95 FOR 1995-SURVIVOR FIRMS

tab cnaesec
* xttrans cnaesec if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* separations (from firms), no unaccounted transitions
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnaesec<9 & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)

* separations (from firms), w/ transitions into unaccounted status
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_unac) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1], m(xts_cnaesec_unac_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1986 & year<=1990, m(xts_cnaesec_unac_86_90) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1994, m(xts_cnaesec_unac_90_94) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
*xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1994 & year<=1998, m(xts_cnaesec_unac_94_98) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_cnaesec_unac_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)
xttrans2tex cnaesec if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_cnaesec_unac_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(tradsec) digits(1) scale(100)

* FIRM TRANSITIONS (EXPORTERS 1990-98)

tab indexp
qui label save indexp using "brazrloc/tex/v4/natl/trans/indexp", replace
* xttrans indexp if cnpj_radic~=cnpj_radic[_n+1]  // current year `was', subsequent year `is' in xttrans.ado

* continuations and separations
xttrans2tex indexp, m(xtcs_indexp) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp, m(xtcs_indexp_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* continuations and separations, reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1], m(xtcs_indexp_insec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1], m(xtcs_indexp_num_insec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_indexp_num_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_indexp_num_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms), reabsorptions within aggregate sector
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_insec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_num_insec) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]

* separations only (separations from firms), reabsorptions within manufacturing
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_manf) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(1) scale(100)
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1], m(xts_indexp_manf_num) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & year>=1990 & year<=1991, m(xts_indexp_manf_num_90_91) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]
xttrans2tex indexp if aggsec==3 & aggsec==aggsec[_n+1] & cnpj_radic~=cnpj_radic[_n+1] & year>=1996 & year<=1997, m(xts_indexp_manf_num_96_97) replace path(brazrloc/tex/v4/natl/trans) fancy vallabel(indexp) digits(3) counts thousep scale(.0001)  // in millions, scaled by 100 to account for 1% sample [100/1000000]


log close
